@@ -1,4 +1,7 @@
 from palp.item.item_base import BaseItem
+from palp.network.request import Request
+from palp.network.response import Response
+from palp.spider.spider_base import BaseSpider
 from palp.spider import Spider, DistributiveSpider
 from palp.pipeline.pipeline_base import BasePipeline
 from palp.network.request_method import RequestGet, RequestPost
