@@ -58,7 +58,7 @@ REQUEST_QUEUE = {
 }
 
 # 下载中间件：请求前的处理
-PIPELINE_ITEM_BUFFER = 100  # item buffer，只有当 item 达到一定数量才会入库，0 为进行缓存
+PIPELINE_ITEM_BUFFER = 0  # 缓存数量，只有当 item 达到一定数量才会入库，0 为不进行缓存
 PIPELINE_RETRY_TIMES = 3  # 入库失败重试次数
 PIPELINE = [
     "palp.pipeline.pipeline_base.BasePipeline",
